@@ -17,10 +17,10 @@ import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@pepperize/cdk-autoscaling-gitlab-runner",
-    "0.0.69",
+    "@pepperize-testing/cdk-autoscaling-gitlab-runner",
+    "0.0.70",
     __name__[0:-6],
-    "cdk-autoscaling-gitlab-runner@0.0.69.jsii.tgz",
+    "cdk-autoscaling-gitlab-runner@0.0.70.jsii.tgz",
 )
 
 __all__ = [
